@@ -6,8 +6,10 @@ else:
     from . import utils
 
 def get_data(root):
+    utils.print_start(root)
     with utils.data_directory(root):
-        os.system(f"kaggle datasets download -d 'aalborguniversity/aau-zebrafish-reid' --unzip")
+        utils.kaggle_download(f"datasets download -d 'aalborguniversity/aau-zebrafish-reid' --unzip")
+    utils.print_finish(root)
 
 
 if __name__ == '__main__':
