@@ -7,6 +7,7 @@ else:
     from . import utils
 
 def get_data(root):
+    utils.print_start(root)
     with utils.data_directory(root):
         # TODO: why not the automatic download?
         # Try automatic download
@@ -20,7 +21,7 @@ def get_data(root):
         url = 'https://drive.google.com/drive/folders/1YkH_2DNVBOKMNGxDinJb97y2T8_wRTZz'
 
         # Upload to kaggle and download
-        os.system(f"kaggle datasets download -d 'vojtacermak/birds' --unzip")
+        utils.kaggle_download(f"datasets download -d 'vojtacermak/birds' --unzip")
 
         # Create new folder for segmented images
         folder_new = os.getcwd() + 'Segmented'
@@ -30,6 +31,8 @@ def get_data(root):
         # Move segmented images to new folder
         folder_move = 'Cropped_pictures'
         shutil.move(folder_move, os.path.join(folder_new, folder_move))
+    utils.print_finish(root)
+
 
 if __name__ == '__main__':
     parser = argparse.ArgumentParser()
