@@ -6,6 +6,7 @@ else:
     from . import utils
 
 def get_data(root):
+    utils.print_start(root)
     with utils.data_directory(root):
         downloads = [
             ('https://github.com/clwitham/MacaqueFaces/raw/master/ModelSet/MacaqueFaces.zip', 'MacaqueFaces.zip'),
@@ -14,6 +15,7 @@ def get_data(root):
         for url, file in downloads:
             utils.download_url(url, file)
         utils.extract_archive('MacaqueFaces.zip', delete=True)
+    utils.print_finish(root)
 
 
 if __name__ == '__main__':
