@@ -7,14 +7,16 @@ else:
     from . import utils
 
 def get_data(root):
+    utils.print_start(root)
     with utils.data_directory(root):
-        os.system(f"kaggle competitions download -c noaa-right-whale-recognition")
+        utils.kaggle_download(f"competitions download -c noaa-right-whale-recognition")
         utils.extract_archive('noaa-right-whale-recognition.zip', delete=True)
         utils.extract_archive('imgs.zip', delete=True)
 
         # Move misplaced image
         shutil.move('w_7489.jpg', 'imgs')
         os.remove('w_7489.jpg.zip')
+    utils.print_finish(root)
 
 
 if __name__ == '__main__':
