@@ -33,4 +33,17 @@ def data_directory(dir):
     try:
         yield
     finally:
-        os.chdir(current_dir)
\ No newline at end of file
+        os.chdir(current_dir)
+
+
+def print_start(root):
+    print('DATASET %s: DOWNLOAD STARTED.' % os.path.split(root)[1])
+
+def print_finish(root):
+    print('DATASET %s: DOWNLOAD FINISHED. If mass downloading, you can remove it from the list.' % os.path.split(root)[1])
+    print('')
+
+def kaggle_download(command):
+    # TODO: add a check that kaggle is installed
+    # TODO: add kaggle as package requirements
+    os.system(f"kaggle {command}")
\ No newline at end of file
