@@ -7,11 +7,13 @@ else:
 
 
 def get_data(root):
+    utils.print_start(root)
     with utils.data_directory(root):
         url = 'https://lilablobssc.blob.core.windows.net/whale-shark-id/whaleshark.coco.tar.gz'
         archive = 'whaleshark.coco.tar.gz'
         utils.download_url(url, archive)
         utils.extract_archive(archive, delete=True)
+    utils.print_finish(root)
 
 
 if __name__ == '__main__':
